#[repr(C)]pub struct RegisterBlock {
pub cr: Reg<CR_SPEC>,
pub ctrl: Reg<CTRL_SPEC>,
pub cntval: Reg<CNTVAL_SPEC>,
}Expand description
Register block
Fields
cr: Reg<CR_SPEC>0x00 - D/A Converter Register. This register contains the digital value to be converted to analog and a power control bit.
ctrl: Reg<CTRL_SPEC>0x04 - DAC Control register. This register controls DMA and timer operation.
cntval: Reg<CNTVAL_SPEC>0x08 - DAC Counter Value register. This register contains the reload value for the DAC DMA/Interrupt timer.