pub struct W(/* private fields */);Expand description
Register CANWAKEFLAGS writer
Implementations
Sourceimpl W
impl W
Sourcepub fn can1wake(&mut self) -> CAN1WAKE_W<'_>
pub fn can1wake(&mut self) -> CAN1WAKE_W<'_>
Bit 1 - Wake-up status for CAN channel 1. Read: when 1, indicates that a falling edge has occurred on the receive data line of CAN channel 1. Write: writing a 1 clears this bit.
Sourcepub fn can2wake(&mut self) -> CAN2WAKE_W<'_>
pub fn can2wake(&mut self) -> CAN2WAKE_W<'_>
Bit 2 - Wake-up status for CAN channel 2. Read: when 1, indicates that a falling edge has occurred on the receive data line of CAN channel 2. Write: writing a 1 clears this bit.
Methods from Deref<Target = W<CANWAKEFLAGS_SPEC>>