R

Struct R 

pub struct R(/* private fields */);
Register PCON reader

Implementations

Source

impl R

pub fn pm0(&self) -> PM0_R

Bit 0 - Power mode control bit 0. This bit controls entry to the Power-down mode.

pub fn pm1(&self) -> PM1_R

Bit 1 - Power mode control bit 1. This bit controls entry to the Deep Power-down mode.

pub fn bodrpm(&self) -> BODRPM_R

Bit 2 - Brown-Out Reduced Power Mode. When BODRPM is 1, the Brown-Out Detect circuitry will be turned off when chip Power-down mode or Deep Sleep mode is entered, resulting in a further reduction in power usage. However, the possibility of using Brown-Out Detect as a wake-up source from the reduced power mode will be lost. When 0, the Brown-Out Detect function remains active during Power-down and Deep Sleep modes. See the System Control Block chapter for details of Brown-Out detection.

pub fn bogd(&self) -> BOGD_R

Bit 3 - Brown-Out Global Disable. When BOGD is 1, the Brown-Out Detect circuitry is fully disabled at all times, and does not consume power. When 0, the Brown-Out Detect circuitry is enabled. See the System Control Block chapter for details of Brown-Out detection. Note: the Brown-Out Reset Disable (BORD, in this register) and the Brown-Out Interrupt (xx) must be disabled when software changes the value of this bit.

pub fn bord(&self) -> BORD_R

Bit 4 - Brown-Out Reset Disable. When BORD is 1, the BOD will not reset the device when the VDD(REG)(3V3) voltage dips goes below the BOD reset trip level. The Brown-Out interrupt is not affected. When BORD is 0, the BOD reset is enabled.

pub fn smflag(&self) -> SMFLAG_R

Bit 8 - Sleep Mode entry flag. Set when the Sleep mode is successfully entered. Cleared by software writing a one to this bit.

pub fn dsflag(&self) -> DSFLAG_R

Bit 9 - Deep Sleep entry flag. Set when the Deep Sleep mode is successfully entered. Cleared by software writing a one to this bit.

pub fn pdflag(&self) -> PDFLAG_R

Bit 10 - Power-down entry flag. Set when the Power-down mode is successfully entered. Cleared by software writing a one to this bit.

pub fn dpdflag(&self) -> DPDFLAG_R

Bit 11 - Deep Power-down entry flag. Set when the Deep Power-down mode is successfully entered. Cleared by software writing a one to this bit.

Methods from Deref<Target = R<PCON_SPEC>>

pub fn bits(&self) -> REG::Ux

Reads raw bits from register.