pub type RITINT_W<'a> = BitWriter<'a, u32, CTRL_SPEC, RITINT_A, 0>;Expand description
Field RITINT writer - Interrupt flag
Aliased Type
pub struct RITINT_W<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RITINT_W<'a>
impl<'a> RITINT_W<'a>
Sourcepub fn this_bit_is_set_to_1(self) -> &'a mut W
pub fn this_bit_is_set_to_1(self) -> &'a mut W
This bit is set to 1 by hardware whenever the counter value equals the masked compare value specified by the contents of RICOMPVAL and RIMASK registers. Writing a 1 to this bit will clear it to 0. Writing a 0 has no effect.
Sourcepub fn the_counter_value_do(self) -> &'a mut W
pub fn the_counter_value_do(self) -> &'a mut W
The counter value does not equal the masked compare value.